# NumPipe

## Features

## Installation
NumPipe can be installed with pip
```shell
pip install numpipe
```

## Usage
See the examples folder for how to use FPlanck.

## License
NumPipe is licensed under the terms of the MIT license.
